ReturnHeaders

ns_write "<html>
<head>
<title>The Keepalive Server at [ns_conn location]</title>
</head>
<body bgcolor=white text=black>

<h2>The Keepalive Server</h2>

at [ns_conn location]

<hr>

The monitor list: 

<ul>

"

ns_share keepalive_monitor_list 

foreach monitor_set $keepalive_monitor_list {
    ns_write "<li>[ns_set get $monitor_set name] ([ns_set get $monitor_set counter] tries remaining out of [ns_set get $monitor_set n_tries]; notify threshold is [ns_set get $monitor_set notify_threshold])\n"
}

ns_write "

</ul>

<hr>

<a href=\"mailto:ben@mit.edu\"><address>ben@mit.edu</address></a>

</body>
</html>
"
