
#
# This file contains the various messages to send out.

proc ka_long_message {service_name return_value n_retries_left action_taken {additional_note ""}} {
    return "
Failure on $service_name.
The following return message was :

$return_value
		
Number of Attempts remaining: $n_retries_left.
    
The following action was taken:
		    
$action_taken

$additional_note

-KeepAlive Monitor
"}

proc ka_short_message {service_name return_value n_retries_left {action_taken ""}} {
    set return_str "$service_name failed.
$n_retries_left retries left.
"
if {$action_taken != ""} {
    append return_str "action: $action_taken\n"
}

return $return_str
}
